package
Version:
v0.0.0-...-f842bd5
Opens a new window with list of versions in this module.
Published: Sep 8, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Asssert(a bool, msg string, args ...interface{})
func AsssertNotEmpty(a string, msg string, args ...interface{})
func AsssertNotNil(a any, msg string, args ...interface{})
func Asssertf(f func() bool, msg string, args ...interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.